@@ -87,7 +87,7 @@ typedef enum  {
   decoder_profiles_HEVC_MAIN_444,    //     {"HEVC_MAIN_444", VDP_DECODER_PROFILE_HEVC_MAIN_444},
   _decoder_maxnull
 }VDP_Decoder_e;
-#define  RET_INFO_LENTH_MAX  (512)
+#define  RET_INFO_LENGTH_MAX  (512)
 typedef struct  {
   VDP_Decoder_e  func; //具体值的功能查询
   VdpBool is_supported; //是否支持具体值硬解码
@@ -95,7 +95,7 @@ typedef struct  {
   uint32_t max_height;//最大支持视频高度
   uint32_t max_level; //最大支持等级
   uint32_t max_macroblocks;//最大宏块大小
-  char ret_info[RET_INFO_LENTH_MAX];//支持的列表
+  char ret_info[RET_INFO_LENGTH_MAX];//支持的列表
 }VDP_Decoder_t;
 //返回值大于0表示支持硬解， index 视频格式解码请求值， result 返回解码支持信息
 typedef unsigned int (*gpu_decoderInfo)(decoder_profile index, VDP_Decoder_t *result );
@@ -566,12 +566,6 @@ mpv_handle *MpvProxy::mpv_init()
             my_set_property(pHandle, "vo", "x11,gpu,xv");
             m_sInitVo = "x11,gpu,xv";
         }
-        if (CompositingManager::get().isSpecialControls()) {
-            qDebug() << "DEBUG: AARCH64: Special controls detected. Setting hwdec to vaapi and vo to vaapi.";
-            my_set_property(pHandle, "hwdec", "vaapi");
-            my_set_property(pHandle, "vo", "vaapi");
-            m_sInitVo = "vaapi";
-        }
 #else
         //去除9200显卡适配
         QFileInfo sjmfi("/dev/jmgpu");
@@ -586,17 +580,9 @@ mpv_handle *MpvProxy::mpv_init()
         //TODO(xxxxpengfei)：暂未处理intel集显情况
         if (CompositingManager::get().isZXIntgraphics() && !jmflag) {
             qDebug() << "DEBUG: ZXIntgraphics detected and no Jingjiawei driver. Checking apt policy.";
-            QProcess process;
-            QStringList options;
-            options << "-c" << QString("apt policy cx4-linux-graphics-driver-dri | sed -n \'2p\'");
-            process.start("/bin/bash", options);
-            process.waitForFinished();
-            process.waitForReadyRead();
-
-            QString error = process.readAllStandardError();
-            if (error.isEmpty()) {
-                QString comStr = process.readAllStandardOutput();
-                comStr = comStr.right(3).left(2);
+            QStringList sList = dmr::utils::runPipeProcess("apt policy cx4-linux-graphics-driver-dri", "");
+            if(sList.count() > 3) {
+                QString comStr = sList.at(2).right(3).left(2);
                 int version = comStr.toInt();
                 qDebug() << "DEBUG: apt policy output version:" << version;
                 if (version >= 10) {
@@ -609,12 +595,6 @@ mpv_handle *MpvProxy::mpv_init()
                     m_sInitVo = "gpu";
                     qDebug() << "DEBUG: Version < 10. Setting vo to gpu.";
                 }
-            } else {
-                qWarning() << "WARNING: apt policy process returned error:" << error;
-                my_set_property(pHandle, "vo", "x11,xv");
-                my_set_property(pHandle, "hwdec", "vaapi");
-                m_sInitVo = "x11,xv";
-                qDebug() << "DEBUG: Error in apt policy. Setting vo to x11,xv and hwdec to vaapi.";
             }
         }
 #endif
@@ -630,7 +610,7 @@ mpv_handle *MpvProxy::mpv_init()
             m_sInitVo = "vaapi";
         }
 
-        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default") && !QFile::exists("/dev/mtgpu.0")) {
             qDebug() << "DEBUG: Ctyun clink registry detected. Setting hwdec to no, vo to x11, video-sync to desync, and profile to sw-fast.";
             my_set_property(pHandle, "hwdec", "no");
             my_set_property(pHandle, "vo", "x11");
@@ -645,6 +625,12 @@ mpv_handle *MpvProxy::mpv_init()
             my_set_property(pHandle, "vo", "gpu,x11");
             m_sInitVo = "gpu,x11";
         }
+
+        if (CompositingManager::get().isSpecialControls()) {
+            my_set_property(pHandle, "hwdec", "vaapi");
+            my_set_property(pHandle, "vo", "vaapi");
+            m_sInitVo = "vaapi";
+        }
     } else { //3.设置硬解
         qDebug() << "DEBUG: Decode mode set to HARDWARE. Checking specific hardware.";
         QFileInfo fi("/dev/mwv206_0");
@@ -704,7 +690,7 @@ mpv_handle *MpvProxy::mpv_init()
             qDebug() << "DEBUG: Loongarch: Specific hardware detected, skipping direct rendering check.";
         }
 #endif
-        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default") && !QFile::exists("/dev/mtgpu.0")) {
             qDebug() << "DEBUG: Ctyun clink registry detected. Setting hwdec to no and vo to x11.";
             my_set_property(pHandle, "hwdec", "no");
             my_set_property(pHandle, "vo", "x11");
@@ -982,12 +968,13 @@ bool isSpecialHWHardware()
         }
 
         if (NotHWDev == s_DevType) {
-            // dmidecode | grep -i "String 4"中的值来区分主板类型,PWC30表示PanguW（也就是W525）
-            process.start("bash", {"-c", "dmidecode -t 11 | grep -i \"String 4\""});
-            process.waitForFinished(100);
-            info = process.readAll();
-            if (info.contains("PWC30") || info.contains("PGUX")) {
-                s_DevType = IsHWDev;
+            // dmidecode | grep -i “String 4”中的值来区分主板类型,PWC30表示PanguW（也就是W525）
+            QStringList sList = dmr::utils::runPipeProcess("dmidecode -t 11", "String 4");
+            foreach(info, sList) {
+                if (info.contains("PWC30") || info.contains("PGUX")) {
+                    s_DevType = IsHWDev;
+                    break;
+                }
             }
         }
 
@@ -997,7 +984,7 @@ bool isSpecialHWHardware()
     return bool(s_DevType == IsHWDev);
 }
 
-bool MpvProxy::isSurportHardWareDecode(const QString sDecodeName, const int &nVideoWidth, const int &nVideoHeight)
+bool MpvProxy::isSupportHardWareDecode(const QString sDecodeName, const int &nVideoWidth, const int &nVideoHeight)
 {
     // FIXME: gpuinfo crash on treeland, so force soft decode on treeland
     if (utils::check_wayland_env()) {
@@ -1016,9 +1003,9 @@ bool MpvProxy::isSurportHardWareDecode(const QString sDecodeName, const int &nVi
     if(decoderValue != decoder_profile::UN_KNOW ) {//开始探测是否支持硬解码
         VDP_Decoder_t *probeDecode = new VDP_Decoder_t;
         if(m_gpuInfo) {
-            int nSurport =  ((gpu_decoderInfo)m_gpuInfo)(decoderValue, probeDecode);
-            isHardWare = (nSurport > 0 && probeDecode->max_width >= nVideoWidth
-                    &&  probeDecode->max_height >= nVideoHeight);//nSurport大于0表示支持，硬解码支持的最大宽高必须大于或等于视频的宽高
+            int nSupport =  ((gpu_decoderInfo)m_gpuInfo)(decoderValue, probeDecode);
+            isHardWare = (nSupport > 0 && probeDecode->max_width >= nVideoWidth
+                    &&  probeDecode->max_height >= nVideoHeight);//nSupport大于0表示支持，硬解码支持的最大宽高必须大于或等于视频的宽高
         }
         delete probeDecode;
     }
@@ -1132,6 +1119,9 @@ void MpvProxy::handle_mpv_events()
                     << "dec:" << my_get_property(m_handle, "video-dec-params/rotate").toInt()
                     << "out:" << my_get_property(m_handle, "video-params/rotate").toInt();
             m_bLoadMedia = false;
+            if(utils::check_wayland_env()) {
+                dmr::utils::switchToDefaultSink();
+            }
             break;
         }
         case MPV_EVENT_VIDEO_RECONFIG: {
@@ -1180,7 +1170,7 @@ void MpvProxy::processLogMessage(mpv_event_log_message *pEvent)
     case MPV_LOG_LEVEL_FATAL: {
         QString strError = pEvent->text;
         if (strError.contains("Failed setup for format vdpau")) {
-            m_bLastIsSpecficFormat = true;
+            m_bLastIsSpecificFormat = true;
         }
         qCritical() << QString("%1: %2").arg(pEvent->prefix).arg(strError);
         emit mpvErrorLogsChanged(QString(pEvent->prefix), strError);
@@ -1515,6 +1505,9 @@ void MpvProxy::refreshDecode()
             auto name = _file.fileName();
             qInfo() << "Codec:" << codec << "Name:" << name;
             isSoftCodec = codec.toLower().contains("mpeg2video") || codec.toLower().contains("wmv") || name.toLower().contains("wmv");
+            if (isSoftCodec) {
+                qWarning() << "Using SoftCodec because of codec OR name";
+            }
             //去除9200显卡适配
             QFileInfo jmfi("/dev/jmgpu");
             QFileInfo fi("/dev/mwv206_0");
@@ -1535,7 +1528,16 @@ void MpvProxy::refreshDecode()
 #if !defined(_loongarch) && !defined(__loongarch__) && !defined(__loongarch64)
             //探测硬解码
             if(!isSoftCodec && !CompositingManager::get().isZXIntgraphics() && !jmflag && !x100flag) {
-                isSoftCodec = !isSurportHardWareDecode(codec, currentInfo.mi.width, currentInfo.mi.height);
+                isSoftCodec = !isSupportHardWareDecode(codec, currentInfo.mi.width, currentInfo.mi.height);
+                if (isSoftCodec) {
+                    qWarning() << "Using SoftCodec because of check SupportHardWareDecode";
+                }
+            }
+            if (CompositingManager::get().isZXIntgraphics() && !jmflag) {
+                isSoftCodec = codec.contains("vp8") && (currentInfo.mi.width > 1920 || currentInfo.mi.height > 1080);
+                if (isSoftCodec) {
+                    qWarning() << "Using SoftCodec because of codec OR size";
+                }
             }
 #endif
             if(utils::check_wayland_env()){
@@ -1543,6 +1545,7 @@ void MpvProxy::refreshDecode()
                 QVariant varPixfmt = playMode->property(currentInfo.mi.filePath.toUtf8());
                 if(varPixfmt.isValid() && varPixfmt.toInt() == AV_PIX_FMT_YUV444P) {
                     isSoftCodec = true;
+                    qWarning() << "Using SoftCodec because of format";
                 }
             }
         }
@@ -1559,6 +1562,7 @@ void MpvProxy::refreshDecode()
                 PlayItemInfo currentInfo = dynamic_cast<PlayerEngine *>(m_pParentWidget)->getplaylist()->currentInfo();
                 auto codec = currentInfo.mi.videoCodec();
                 if (codec.toLower().contains("mpeg2") || codec.toLower().contains("mpeg4")) {
+                    qWarning() << "Using SoftCodec because of codec";
                     my_set_property(m_handle, "hwdec", "no");
                 } else {
                     QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206"); //判断是否安装核外驱动
@@ -1573,10 +1577,14 @@ void MpvProxy::refreshDecode()
                         my_set_property(m_handle, "hwdec", "auto");
                     }
                 }
+#ifdef _LIBDMR_
+    my_set_property(m_handle, "vo", "libmpv,opengl-cb");
+#endif
             } else if (X100GPU.exists() && X100VPU.exists()) {
                 my_set_property(m_handle, "hwdec", "ftomx-copy");
                 my_set_property(m_handle, "vo", "gpu");
             } else if (CompositingManager::get().isOnlySoftDecode()) { //2.2.1.2 鲲鹏920 || 曙光+英伟达 || 浪潮
+                qWarning() << "Using SoftCodec because of OnlySoftDecode";
                 my_set_property(m_handle, "hwdec", "no");
             } else if (CompositingManager::get().isSpecialControls()) {
                 my_set_property(m_handle, "hwdec", "vaapi");
@@ -1594,7 +1602,7 @@ void MpvProxy::refreshDecode()
             my_set_property(m_handle, "hwdec", "vaapi");
         }
 
-        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default") && !QFile::exists("/dev/mtgpu.0")) {
             my_set_property(m_handle, "hwdec", "no");
             my_set_property(m_handle, "vo", "x11");
             my_set_property(m_handle, "video-sync", "desync");
@@ -1607,6 +1615,7 @@ void MpvProxy::refreshDecode()
 #if defined (__aarch64__)
         // 鲲鹏920 || 曙光+英伟达 || 浪潮
         if (!CompositingManager::get().hascard() || CompositingManager::get().isOnlySoftDecode()) {
+            qWarning() << "Using SoftCodec because of hascard OR OnlySoftDecode";
             my_set_property(m_handle, "hwdec", "no");
         } else if (CompositingManager::get().isSpecialControls()) {
             my_set_property(m_handle, "hwdec", "vaapi");
@@ -1615,6 +1624,7 @@ void MpvProxy::refreshDecode()
         }
 #else
         if(CompositingManager::get().isOnlySoftDecode()) {
+            qWarning() << "Using SoftCodec because of OnlySoftDecode";
             my_set_property(m_handle, "hwdec","no");
         } else {
             my_set_property(m_handle, "hwdec","auto");
@@ -1623,6 +1633,7 @@ void MpvProxy::refreshDecode()
 
 #else
         if (CompositingManager::get().isOnlySoftDecode()) { // 鲲鹏920 || 曙光+英伟达 || 浪潮
+            qWarning() << "Using SoftCodec because of OnlySoftDecode";
             my_set_property(m_handle, "hwdec", "no");
         } else {
              my_set_property(m_handle, "hwdec","auto");
@@ -1645,6 +1656,9 @@ void MpvProxy::refreshDecode()
             }else {
                 my_set_property(m_handle, "hwdec", "auto");
             }
+#ifdef _LIBDMR_
+    my_set_property(m_handle, "vo", "libmpv,opengl-cb");
+#endif
         } else if (X100GPU.exists() && X100VPU.exists()) {
             qDebug() << "DEBUG: X100 GPU/VPU detected (harddec mode). Setting hwdec to ftomx-copy, vo to gpu.";
             my_set_property(m_handle, "hwdec", "ftomx-copy");
@@ -1655,7 +1669,7 @@ void MpvProxy::refreshDecode()
             my_set_property(m_handle, "hwdec", "vaapi");
         }
 
-        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default") && !QFile::exists("/dev/mtgpu.0")) {
             my_set_property(m_handle, "hwdec", "no");
             my_set_property(m_handle, "vo", "x11");
             my_set_property(m_handle, "video-sync", "desync");
@@ -1668,6 +1682,7 @@ void MpvProxy::refreshDecode()
             PlayItemInfo currentInfo = playMode->currentInfo();
             QVariant varPixfmt = playMode->property(currentInfo.mi.filePath.toUtf8());
             if(varPixfmt.isValid() && varPixfmt.toInt() == AV_PIX_FMT_YUV444P) {
+                qWarning() << "Using SoftCodec because of format";
                 my_set_property(m_handle, "hwdec","no");
             }
         }
@@ -1675,12 +1690,12 @@ void MpvProxy::refreshDecode()
         //play.conf
         CompositingManager::get().getMpvConfig(m_pConfig);
 #ifndef _LIBDMR_
-    if (Settings::get().settings()->getOption(QString("base.decode.select")).toInt() == 3) {
-        int decodeIndex = Settings::get().settings()->getOption(QString("base.decode.Decodemode")).toInt();
-        auto decodeModeOpt = Settings::get().settings()->option("base.decode.Decodemode");
-        QString decodeMode = decodeModeOpt.data()->data("items").toStringList()[decodeIndex];
-        decodeMode = decodeMode.isEmpty() ? "auto" : decodeMode;
-        m_pConfig->insert("hwdec", decodeMode);
+        if (Settings::get().settings()->getOption(QString("base.decode.select")).toInt() == 3) {
+            int decodeIndex = Settings::get().settings()->getOption(QString("base.decode.Decodemode")).toInt();
+            auto decodeModeOpt = Settings::get().settings()->option("base.decode.Decodemode");
+            QString decodeMode = decodeModeOpt.data()->data("items").toStringList()[decodeIndex];
+            decodeMode = decodeMode.isEmpty() ? "auto" : decodeMode;
+            m_pConfig->insert("hwdec", decodeMode);
 
             if (!CompositingManager::get().composited()) {
                 int voIndex = Settings::get().settings()->getOption(QString("base.decode.Videoout")).toInt();
@@ -1719,7 +1734,7 @@ void MpvProxy::initMember()
     m_bIsJingJia = false;
     m_bInited = false;
     m_bHwaccelAuto = false;
-    m_bLastIsSpecficFormat = false;
+    m_bLastIsSpecificFormat = false;
 
     m_sInitVo = "gpu,xv,x11";//初始化vo数据
     m_listBurstPoints.clear();
@@ -1826,8 +1841,9 @@ void MpvProxy::play()
         QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206");
         QString sCodec = pEngine->playlist().currentInfo().mi.videoCodec();
         if(sdir.exists() && sCodec.contains("avs2", Qt::CaseInsensitive)) {
-             my_set_property(m_handle, "hwdec", "no");
-             my_set_property(m_handle, "vo", "gpu,x11,xv");
+            qWarning() << "Using SoftCodec because of codec";
+            my_set_property(m_handle, "hwdec", "no");
+            my_set_property(m_handle, "vo", "gpu,x11,xv");
         }
     }
 
@@ -1849,6 +1865,8 @@ void MpvProxy::play()
         my_set_property(m_handle, iter.key(), iter.value());
         iter++;
     }
+    qInfo() << "FINALLY, hwdec:" << my_get_property(m_handle, "hwdec").toString();
+    qInfo() << "FINALLY, vo:" << my_get_property(m_handle, "vo").toString();
 
     qInfo() << "Executing play command with args:" << listArgs << "and options:" << listOpts;
     my_command(m_handle, listArgs);
