@@ -361,7 +361,7 @@ protected:
     /**
      * @brief 是否支持硬件解码
      */
-    bool isSurportHardWareDecode(const QString sDecodeName, const int &nVideoWidth, const int &nVideoHeight);
+    bool isSupportHardWareDecode(const QString sDecodeName, const int &nVideoWidth, const int &nVideoHeight);
     /**
      * @brief 获取探测解码值
      */
@@ -433,7 +433,7 @@ private:
     bool m_bIsJingJia;                     //是否在景嘉微平台上
     bool m_bInited;                        //mpv是否已经初始化
     bool m_bHwaccelAuto;                   //如果设置为不为自动，则不允许此类改变硬件设置
-    bool m_bLastIsSpecficFormat;           //上一曲是否是特殊格式的影片，如果是则应该重新设置vo
+    bool m_bLastIsSpecificFormat;           //上一曲是否是特殊格式的影片，如果是则应该重新设置vo
     QMap<QString, QVariant> m_mapWaitSet;  //等待mpv初始化后设置的参数
     QVector<QVariant> m_vecWaitCommand;    //等待mpv初始化后设置的参数
     //mpv播放配置
