@@ -12,9 +12,12 @@ namespace dmr {
 static ActionFactory *pActionFactory = nullptr;
 ActionFactory &ActionFactory::get()
 {
+    qDebug() << "Entering ActionFactory::get().";
     if (pActionFactory == nullptr) {
+        qDebug() << "pActionFactory is null, creating new ActionFactory instance.";
         pActionFactory = new ActionFactory();
     }
+    qDebug() << "Exiting ActionFactory::get(). Returning instance.";
     return *pActionFactory;
 }
 #define DEF_ACTION(NAME, KD) do { \
@@ -48,10 +51,13 @@ ActionFactory &ActionFactory::get()
     } while (0)
 DMenu *ActionFactory::titlebarMenu()
 {
+    qDebug() << "Entering ActionFactory::titlebarMenu().";
     if (!m_pTitlebarMenu) {
+        qDebug() << "Titlebar menu is null, creating new titlebar menu.";
         DMenu *pMenu_p = new DMenu();
         DEF_ACTION(tr("Open file"), ActionKind::OpenFileList);
         if (!CompositingManager::isPadSystem()) {
+            qDebug() << "System is not a pad system. Adding desktop menu items.";
             DEF_ACTION(tr("Open folder"), ActionKind::OpenDirectory);
             DEF_ACTION(tr("Settings"), ActionKind::Settings);
             pMenu_p->addSeparator();
@@ -60,19 +66,17 @@ DMenu *ActionFactory::titlebarMenu()
             //DEF_ACTION("Help", ActionKind::Help);
             //DEF_ACTION("Exit", ActionKind::Exit);
         } else {
+            qDebug() << "System is a pad system. Adding pad menu items.";
             m_pTitlebarMenu = pMenu_p;
             {
                 DMenu *pParent = pMenu_p;
-                DMenu *pMenu = new DMenu(tr("Play"));
+                DMenu *pMenu = new DMenu(tr("Play Mode"));
                 QActionGroup *pActionGroup = new QActionGroup(pMenu);
-                DEF_ACTION_GROUP(tr("Previous"), ActionKind::GotoPlaylistPrev, pActionGroup);
-                DEF_ACTION_GROUP(tr("Next"), ActionKind::GotoPlaylistNext, pActionGroup);
-                pMenu->addSeparator();
-                DEF_ACTION_CHECKED_GROUP(tr("Order play"), ActionKind::OrderPlay, pActionGroup);
-                DEF_ACTION_CHECKED_GROUP(tr("Shuffle play"), ActionKind::ShufflePlay, pActionGroup);
-                DEF_ACTION_CHECKED_GROUP(tr("Single play"), ActionKind::SinglePlay, pActionGroup);
-                DEF_ACTION_CHECKED_GROUP(tr("Single loop"), ActionKind::SingleLoop, pActionGroup);
-                DEF_ACTION_CHECKED_GROUP(tr("List loop"), ActionKind::ListLoop, pActionGroup);
+                DEF_ACTION_CHECKED_GROUP(tr("Order Play"), ActionKind::OrderPlay, pActionGroup);
+                DEF_ACTION_CHECKED_GROUP(tr("Shuffle Play"), ActionKind::ShufflePlay, pActionGroup);
+                DEF_ACTION_CHECKED_GROUP(tr("Single Play"), ActionKind::SinglePlay, pActionGroup);
+                DEF_ACTION_CHECKED_GROUP(tr("Single Loop"), ActionKind::SingleLoop, pActionGroup);
+                DEF_ACTION_CHECKED_GROUP(tr("List Loop"), ActionKind::ListLoop, pActionGroup);
                 pParent->addMenu(pMenu);
             }
             {
@@ -89,8 +93,8 @@ DMenu *ActionFactory::titlebarMenu()
                 DEF_ACTION_GROUP(tr("Clockwise"), ActionKind::ClockwiseFrame, pActionGroup);
                 DEF_ACTION_GROUP(tr("Counterclockwise"), ActionKind::CounterclockwiseFrame, pActionGroup);
                 pMenu->addSeparator();
-                DEF_ACTION_GROUP(tr("Next frame"), ActionKind::NextFrame, pActionGroup);
-                DEF_ACTION_GROUP(tr("Previous frame"), ActionKind::PreviousFrame, pActionGroup);
+                DEF_ACTION_GROUP(tr("Next Frame"), ActionKind::NextFrame, pActionGroup);
+                DEF_ACTION_GROUP(tr("Previous Frame"), ActionKind::PreviousFrame, pActionGroup);
                 pParent->addMenu(pMenu);
                 pMenu->setEnabled(false);
                 connect(this, &ActionFactory::frameMenuEnable, this, [ = ](bool statu) {
@@ -99,7 +103,7 @@ DMenu *ActionFactory::titlebarMenu()
             }
             {
                 DMenu *pParent = pMenu_p;
-                DMenu *pMenu = new DMenu(tr("Playback speed"));
+                DMenu *pMenu = new DMenu(tr("Playback Speed"));
                 QActionGroup *pActionGroup = new QActionGroup(pMenu);
                 DEF_ACTION_CHECKED_GROUP(tr("0.5x"), ActionKind::ZeroPointFiveTimes, pActionGroup);
                 DEF_ACTION_CHECKED_GROUP(tr("1.0x"), ActionKind::OneTimes, pActionGroup);
@@ -115,17 +119,23 @@ DMenu *ActionFactory::titlebarMenu()
         }
 
         m_pTitlebarMenu = pMenu_p;
+        qInfo() << "Titlebar menu created successfully";
     }
+    qDebug() << "Exiting ActionFactory::titlebarMenu(). Returning existing menu.";
     return m_pTitlebarMenu;
 }
 
 DMenu *ActionFactory::mainContextMenu()
 {
+    qDebug() << "Entering ActionFactory::mainContextMenu().";
     if(m_pContextMenu) {
-       return m_pContextMenu;
+        qDebug() << "Context menu already exists. Returning existing context menu.";
+        return m_pContextMenu;
     }
 
+    qDebug() << "Context menu is null. Creating new main context menu.";
     if (CompositingManager::isMpvExists()) {
+        qDebug() << "MPV exists. Creating MPV-enabled context menu.";
         DMenu *pMenu_p = new DMenu();
         DEF_ACTION(tr("Open file"), ActionKind::OpenFileList);
         DEF_ACTION(tr("Open folder"), ActionKind::OpenDirectory);
@@ -133,26 +143,23 @@ DMenu *ActionFactory::mainContextMenu()
         DEF_ACTION(tr("Open CD/DVD"), ActionKind::OpenCdrom);
         pMenu_p->addSeparator();
         DEF_ACTION_CHECKED(tr("Fullscreen"), ActionKind::ToggleFullscreen);
-        DEF_ACTION_CHECKED(tr("Mini mode"), ActionKind::ToggleMiniMode);
+        DEF_ACTION_CHECKED(tr("Mini Mode"), ActionKind::ToggleMiniMode);
         DEF_ACTION_CHECKED(tr("Always on Top"), ActionKind::WindowAbove);
         pMenu_p->addSeparator();
         {
             DMenu *pParent = pMenu_p;         //这里使用代码块和局部变量为了使结构清晰
-            DMenu *pMenu = new DMenu(tr("Play"));
+            DMenu *pMenu = new DMenu(tr("Play Mode"));
             QActionGroup *pActionGroup = new QActionGroup(pMenu);
-            DEF_ACTION_GROUP(tr("Previous"), ActionKind::GotoPlaylistPrev, pActionGroup);
-            DEF_ACTION_GROUP(tr("Next"), ActionKind::GotoPlaylistNext, pActionGroup);
-            pMenu->addSeparator();
-            DEF_ACTION_CHECKED_GROUP(tr("Order play"), ActionKind::OrderPlay, pActionGroup);
-            DEF_ACTION_CHECKED_GROUP(tr("Shuffle play"), ActionKind::ShufflePlay, pActionGroup);
-            DEF_ACTION_CHECKED_GROUP(tr("Single play"), ActionKind::SinglePlay, pActionGroup);
-            DEF_ACTION_CHECKED_GROUP(tr("Single loop"), ActionKind::SingleLoop, pActionGroup);
-            DEF_ACTION_CHECKED_GROUP(tr("List loop"), ActionKind::ListLoop, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("Order Play"), ActionKind::OrderPlay, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("Shuffle Play"), ActionKind::ShufflePlay, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("Single Play"), ActionKind::SinglePlay, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("Single Loop"), ActionKind::SingleLoop, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("List Loop"), ActionKind::ListLoop, pActionGroup);
             pParent->addMenu(pMenu);
         }
         {
             DMenu *pParent = pMenu_p;
-            DMenu *pMenu = new DMenu(tr("Playback speed"));
+            DMenu *pMenu = new DMenu(tr("Playback Speed"));
             QActionGroup *pActionGroup = new QActionGroup(pMenu);
             DEF_ACTION_CHECKED_GROUP(tr("0.5x"), ActionKind::ZeroPointFiveTimes, pActionGroup);
             DEF_ACTION_CHECKED_GROUP(tr("1.0x"), ActionKind::OneTimes, pActionGroup);
@@ -179,8 +186,8 @@ DMenu *ActionFactory::mainContextMenu()
             DEF_ACTION_GROUP(tr("Clockwise"), ActionKind::ClockwiseFrame, pActionGroup);
             DEF_ACTION_GROUP(tr("Counterclockwise"), ActionKind::CounterclockwiseFrame, pActionGroup);
             pMenu->addSeparator();
-            DEF_ACTION_GROUP(tr("Next frame"), ActionKind::NextFrame, pActionGroup);
-            DEF_ACTION_GROUP(tr("Previous frame"), ActionKind::PreviousFrame, pActionGroup);
+            DEF_ACTION_GROUP(tr("Next Frame"), ActionKind::NextFrame, pActionGroup);
+            DEF_ACTION_GROUP(tr("Previous Frame"), ActionKind::PreviousFrame, pActionGroup);
             pParent->addMenu(pMenu);
             pMenu->setEnabled(false);
             connect(this, &ActionFactory::frameMenuEnable, this, [ = ](bool statu) {
@@ -220,14 +227,15 @@ DMenu *ActionFactory::mainContextMenu()
             DMenu *pMenu = new DMenu(tr("Subtitle"));
             QActionGroup *pActionGroup = new QActionGroup(pMenu);
             DEF_ACTION_GROUP(tr("Load"), ActionKind::LoadSubtitle, pActionGroup);
-            DEF_ACTION_GROUP(tr("Online search"), ActionKind::MatchOnlineSubtitle, pActionGroup);
+            DEF_ACTION_GROUP(tr("Online Search"), ActionKind::MatchOnlineSubtitle, pActionGroup);
             //DEF_ACTION(tr("Select"), ActionKind::SelectSubtitle);
             {
                 DMenu *pParent_select = pMenu;
-                DMenu *pMenu = new DMenu(tr("Select"));
-                m_pSubtitleMenu = pMenu;
-                pParent_select->addMenu(pMenu);
+                DMenu *pMenutemp = new DMenu(tr("Select"));
+                m_pSubtitleMenu = pMenutemp;
+                pParent_select->addMenu(pMenutemp);
             }
+            DEF_ACTION_CHECKED_NEW(tr("Hide"), ActionKind::HideSubtitle);
             {
                 DMenu *parent_encoding = pMenu;
                 DMenu *pMenu = new DMenu(tr("Encodings"));
@@ -300,8 +308,8 @@ DMenu *ActionFactory::mainContextMenu()
             DMenu *pMenu = new DMenu(tr("Screenshot"));
             //cppcheck 误报
             QActionGroup *pActionGroup = new QActionGroup(pMenu);
-            DEF_ACTION_GROUP(tr("Film screenshot"), ActionKind::Screenshot, pActionGroup);
-            DEF_ACTION_GROUP(tr("Burst shooting"), ActionKind::BurstScreenshot, pActionGroup);
+            DEF_ACTION_GROUP(tr("Film Screenshot"), ActionKind::Screenshot, pActionGroup);
+            DEF_ACTION_GROUP(tr("Burst Shooting"), ActionKind::BurstScreenshot, pActionGroup);
             DEF_ACTION_GROUP(tr("Open screenshot folder"), ActionKind::GoToScreenshotSolder, pActionGroup);
             pMenu->setEnabled(false);
             parent->addMenu(pMenu);
@@ -311,10 +319,12 @@ DMenu *ActionFactory::mainContextMenu()
         }
         pMenu_p->addSeparator();
         DEF_ACTION_CHECKED(tr("Playlist"), ActionKind::TogglePlaylist);
-        DEF_ACTION(tr("Film info"), ActionKind::MovieInfo);
+        DEF_ACTION(tr("Film Info"), ActionKind::MovieInfo);
         DEF_ACTION(tr("Settings"), ActionKind::Settings);
         m_pContextMenu = pMenu_p;
+        qDebug() << "MPV context menu created successfully.";
     } else {
+        qDebug() << "MPV not found. Creating non-MPV context menu.";
         DMenu *pMenu_p = new DMenu();
         DEF_ACTION(tr("Open file"), ActionKind::OpenFileList);
         DEF_ACTION(tr("Open folder"), ActionKind::OpenDirectory);
@@ -322,26 +332,23 @@ DMenu *ActionFactory::mainContextMenu()
         DEF_ACTION(tr("Open CD/DVD"), ActionKind::OpenCdrom);
         pMenu_p->addSeparator();
         DEF_ACTION_CHECKED(tr("Fullscreen"), ActionKind::ToggleFullscreen);
-        DEF_ACTION_CHECKED(tr("Mini mode"), ActionKind::ToggleMiniMode);
+        DEF_ACTION_CHECKED(tr("Mini Mode"), ActionKind::ToggleMiniMode);
         DEF_ACTION_CHECKED(tr("Always on Top"), ActionKind::WindowAbove);
         pMenu_p->addSeparator();
         {
             DMenu *pParent = pMenu_p;         //这里使用代码块和局部变量为了使结构清晰
-            DMenu *pMenu = new DMenu(tr("Play"));
+            DMenu *pMenu = new DMenu(tr("Play Mode"));
             QActionGroup *pActionGroup = new QActionGroup(pMenu);
-            DEF_ACTION_GROUP(tr("Previous"), ActionKind::GotoPlaylistPrev, pActionGroup);
-            DEF_ACTION_GROUP(tr("Next"), ActionKind::GotoPlaylistNext, pActionGroup);
-            pMenu->addSeparator();
-            DEF_ACTION_CHECKED_GROUP(tr("Order play"), ActionKind::OrderPlay, pActionGroup);
-            DEF_ACTION_CHECKED_GROUP(tr("Shuffle play"), ActionKind::ShufflePlay, pActionGroup);
-            DEF_ACTION_CHECKED_GROUP(tr("Single play"), ActionKind::SinglePlay, pActionGroup);
-            DEF_ACTION_CHECKED_GROUP(tr("Single loop"), ActionKind::SingleLoop, pActionGroup);
-            DEF_ACTION_CHECKED_GROUP(tr("List loop"), ActionKind::ListLoop, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("Order Play"), ActionKind::OrderPlay, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("Shuffle Play"), ActionKind::ShufflePlay, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("Single Play"), ActionKind::SinglePlay, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("Single Loop"), ActionKind::SingleLoop, pActionGroup);
+            DEF_ACTION_CHECKED_GROUP(tr("List Loop"), ActionKind::ListLoop, pActionGroup);
             pParent->addMenu(pMenu);
         }
         {
             DMenu *pParent = pMenu_p;
-            DMenu *pMenu = new DMenu(tr("Playback speed"));
+            DMenu *pMenu = new DMenu(tr("Playback Speed"));
             QActionGroup *pActionGroup = new QActionGroup(pMenu);
             DEF_ACTION_CHECKED_GROUP(tr("0.5x"), ActionKind::ZeroPointFiveTimes, pActionGroup);
             DEF_ACTION_CHECKED_GROUP(tr("1.0x"), ActionKind::OneTimes, pActionGroup);
@@ -360,7 +367,7 @@ DMenu *ActionFactory::mainContextMenu()
             DMenu *pMenu = new DMenu(tr("Screenshot"));
             //cppcheck 误报
             QActionGroup *pActionGroup = new QActionGroup(pMenu);
-            DEF_ACTION_GROUP(tr("Film screenshot"), ActionKind::Screenshot, pActionGroup);
+            DEF_ACTION_GROUP(tr("Film Screenshot"), ActionKind::Screenshot, pActionGroup);
             DEF_ACTION_GROUP(tr("Open screenshot folder"), ActionKind::GoToScreenshotSolder, pActionGroup);
             pMenu->setEnabled(false);
             parent->addMenu(pMenu);
@@ -370,26 +377,33 @@ DMenu *ActionFactory::mainContextMenu()
         }
         pMenu_p->addSeparator();
         DEF_ACTION_CHECKED(tr("Playlist"), ActionKind::TogglePlaylist);
-        DEF_ACTION(tr("Film info"), ActionKind::MovieInfo);
+        DEF_ACTION(tr("Film Info"), ActionKind::MovieInfo);
         DEF_ACTION(tr("Settings"), ActionKind::Settings);
         m_pContextMenu = pMenu_p;
+        qDebug() << "Non-MPV context menu created successfully.";
     }
+    qDebug() << "Exiting ActionFactory::mainContextMenu(). Returning context menu.";
     return m_pContextMenu;
 }
 DMenu *ActionFactory::playlistContextMenu()
 {
+    qDebug() << "Entering ActionFactory::playlistContextMenu().";
     if (!m_pPlaylistMenu) {
+        qDebug() << "Playlist menu is null. Creating new playlist context menu.";
         DMenu *pMenu_p = new DMenu();
         DEF_ACTION(tr("Delete from playlist"), ActionKind::PlaylistRemoveItem);
         DEF_ACTION(tr("Empty playlist"), ActionKind::EmptyPlaylist);
         DEF_ACTION(tr("Display in file manager"), ActionKind::PlaylistOpenItemInFM);
         DEF_ACTION(tr("Film info"), ActionKind::PlaylistItemInfo);
         m_pPlaylistMenu = pMenu_p;
+        qDebug() << "Playlist context menu created successfully.";
     }
+    qDebug() << "Exiting ActionFactory::playlistContextMenu(). Returning existing menu.";
     return m_pPlaylistMenu;
 }
 QList<QAction *> ActionFactory::findActionsByKind(ActionKind target_kd)
 {
+    qDebug() << "Finding actions by kind:" << static_cast<int>(target_kd);
     QList<QAction *> listAction;
     auto itor = m_listContextMenuActions.begin();
     while (itor != m_listContextMenuActions.end()) {
@@ -403,37 +417,40 @@ QList<QAction *> ActionFactory::findActionsByKind(ActionKind target_kd)
         }
         ++itor;
     }
+    qDebug() << "Found" << listAction.size() << "matching actions";
     return listAction;
 }
 void ActionFactory::updateMainActionsForMovie(const PlayingMovieInfo &pmf)
 {
-    qInfo() << __func__;
+    qInfo() << "Updating main actions for movie";
     if (m_pSubtitleMenu) {
+        qDebug() << "Updating subtitle menu with" << pmf.subs.size() << "subtitles";
         DMenu *pMenu = m_pSubtitleMenu;
         pMenu->clear();
         if (!m_pSubgroup) {
             m_pSubgroup = new QActionGroup(pMenu); // mem leak ?
         }
-        DEF_ACTION_CHECKED_GROUP(tr("None"), ActionKind::HideSubtitle, m_pSubgroup);
-        QAction *pAct = pMenu->actions().first();
-        pAct->setChecked(true);
-        pAct->setEnabled(true);
         for (int i = 0; i < pmf.subs.size(); i++) {
             DEF_ACTION_CHECKED_GROUP(pmf.subs[i]["title"].toString(), ActionKind::SelectSubtitle, m_pSubgroup);
             QAction *pAct = pMenu->actions().last();
-            pAct->setProperty("args", QList<QVariant>() << i+1);
+            pAct->setProperty("args", QList<QVariant>() << i);
         }
+        m_pSubtitleMenu->setEnabled(pmf.subs.size() > 0);
     }
     if (m_pSound) {
+        qDebug() << "Updating sound menu with" << pmf.audios.size() << "audio tracks";
         DMenu *pMenu = m_pTracksMenu;
         pMenu->clear();
         if (!m_pAudiosgroup) {
+            qDebug() << "m_pAudiosgroup is null";
             m_pAudiosgroup = new QActionGroup(pMenu); // mem leak ?
         }
         for (int i = 0; i < pmf.audios.size(); i++) {
             if (pmf.audios[i]["title"].toString().compare("[internal]") == 0) {
+                qDebug() << "title is [internal]";
                 DEF_ACTION_CHECKED_GROUP(tr("Track") + QString::number(i + 1), ActionKind::SelectTrack, m_pAudiosgroup);
             } else {
+                qDebug() << "title is not [internal]";
                 DEF_ACTION_CHECKED_GROUP(pmf.audios[i]["title"].toString(), ActionKind::SelectTrack, m_pAudiosgroup);
             }
             QAction *pAct = pMenu->actions().last();
@@ -443,13 +460,16 @@ void ActionFactory::updateMainActionsForMovie(const PlayingMovieInfo &pmf)
         m_pSoundMenu->setEnabled(pmf.audios.size() > 0);
         m_pSound->setEnabled(pmf.audios.size() > 0);
     }
+    qInfo() << "Main actions updated successfully";
 }
 ActionFactory::ActionFactory()
 {
+    qDebug() << "ActionFactory";
     initMember();
 }
 void ActionFactory::initMember()
 {
+    qDebug() << "initMember";
     m_pTitlebarMenu = nullptr;
     m_pContextMenu = nullptr;
     m_pSubtitleMenu = nullptr;
@@ -460,6 +480,7 @@ void ActionFactory::initMember()
     m_pSubgroup = nullptr;
     m_pAudiosgroup = nullptr;
     m_listContextMenuActions.clear();
+    qDebug() << "initMember end";
 }
 #undef DEF_ACTION
 #undef DEF_ACTION_CHECKED
