@@ -94,23 +94,17 @@ Settings::Settings()
                     voFamily->setData("items", QStringList() << "OpenGL");
                     auto decodeFamily = m_pSettings->option("base.decode.Decodemode");
                     if (decodeFamily) {
-                         qDebug() << "Setting decode mode items for OpenGL effect.";
-                         decodeFamily->setData("items", QStringList() << "vaapi" << "vaapi-copy" << "vdpau" << "vdpau-copy");
+                        qDebug() << "Setting decode mode items for OpenGL effect.";
+                        decodeFamily->setData("items", QStringList() << "vaapi" << "vaapi-copy" << "vdpau" << "vdpau-copy");
                     }
                 }
-            } else if (index == 2) {
-                qDebug() << "Effect index is 2. Setting video output options and decode mode items.";
-                if (voFamily) {
-                    if (voFamily->value().toInt() == 0) {
-                        auto decodeFamily = m_pSettings->option("base.decode.Decodemode");
-                        if (decodeFamily) {
-                             qDebug() << "Video output is 0 and effect is 2. Clearing decode mode items.";
-                             decodeFamily->setData("items", QStringList());
-                        }
-                    }
-                    qDebug() << "Setting video output options for effect 2.";
-                    voFamily->setData("items", QStringList() << "" << "gpu" << "vaapi" << "vdpau" << "xv" << "x11");
-                }
+            } else if (index == 0) {
+                if (voFamily)
+                    voFamily->setData("items", QStringList() << "gpu"
+                                                             << "vaapi"
+                                                             << "vdpau"
+                                                             << "xv"
+                                                             << "x11");
             }
             emit baseChanged(key, value);
             qDebug() << "Emitted baseChanged for Effect mode.";
@@ -137,10 +131,23 @@ Settings::Settings()
                 if (decodeFamily)
                     decodeFamily->setData("items", QStringList() << "vdpau" << "vdpau-copy");
                 qDebug() << "Setting decode mode items for xv/x11 video output.";
-            } else {
+            } else if (vo.contains("gpu")){
                 if (decodeFamily)
-                    decodeFamily->setData("items", QStringList() << "vaapi" << "vaapi-copy" << "vdpau" << "vdpau-copy" << "nvdec" << "nvdec-copy" << "rkmpp");
-                qDebug() << "Setting default decode mode items for other video output.";
+                    decodeFamily->setData("items", QStringList() << "vaapi"
+                                                                 << "vaapi-copy"
+                                                                 << "vdpau"
+                                                                 << "vdpau-copy"
+                                                                 << "nvdec"
+                                                                 << "nvdec-copy"
+                                                                 << "rkmpp");
+            } else if(vo.contains("opengl", Qt::CaseInsensitive)){
+                if (decodeFamily)
+                    decodeFamily->setData("items", QStringList() << "vaapi"
+                                                                 << "vaapi-copy"
+                                                                 << "vdpau"
+                                                                 << "vdpau-copy"
+                                                                 << "omx"
+                                                                 << "omx-copy");
             }
             emit baseChanged(key, value);
             qDebug() << "Emitted baseChanged for Videoout mode.";
@@ -217,15 +224,29 @@ Settings::Settings()
         auto decodeFamily = m_pSettings->option("base.decode.Decodemode");
         if (decodeFamily) {
             qDebug() << "Setting decode mode items for Wayland.";
-            decodeFamily->setData("items", QStringList() << "vaapi" << "vaapi-copy" << "vdpau" << "vdpau-copy" << "nvdec" << "nvdec-copy" << "rkmpp");
+            decodeFamily->setData("items", QStringList() << "vaapi"
+                                                         << "vaapi-copy"
+                                                         << "vdpau"
+                                                         << "vdpau-copy"
+                                                         << "omx"
+                                                         << "omx-copy");
         } else {
             qWarning() << "Decode mode family option not found for Wayland configuration!";
         }
     } else {
         qDebug() << "X11 environment detected. Configuring video output and decode mode options.";
         QStringList hwdecList, voList;
-        hwdecList << "vaapi" << "vaapi-copy" << "vdpau" << "vdpau-copy" << "nvdec" << "nvdec-copy" << "rkmpp";
-        voList << "gpu" << "vaapi" << "vdpau" << "xv" << "x11";
+        hwdecList << "vaapi"
+                  << "vaapi-copy"
+                  << "vdpau"
+                  << "vdpau-copy"
+                  << "omx"
+                  << "omx-copy";
+        voList << "gpu"
+               << "vaapi"
+               << "vdpau"
+               << "xv"
+               << "x11";
         int effectIndex = m_pSettings->getOption("base.decode.Effect").toInt();
         qDebug() << "X11: Current effectIndex:" << effectIndex;
         auto hwdecFamily = m_pSettings->option("base.decode.Decodemode");
@@ -246,39 +267,45 @@ Settings::Settings()
                 qWarning() << "X11: Hardware decode family option not found for high effect mode!";
             }
         } else {
-            qDebug() << "X11: Effect index is not 1. Setting standard effect mode options.";
-            auto voFamily = m_pSettings->option("base.decode.Videoout");
-            if (voFamily) {
-                qDebug() << "X11: Setting video output options for standard effect mode.";
-                voFamily->setData("items", QStringList() << "" << "gpu" << "vaapi" << "vdpau" << "xv" << "x11");
-            } else {
-                qWarning() << "X11: Video output family option not found for standard effect mode!";
+            if(effectIndex == 0){
+                auto voFamily = m_pSettings->option("base.decode.Videoout");
+                if (voFamily)
+                    voFamily->setData("items", QStringList() << "gpu"
+                                                             << "vaapi"
+                                                             << "vdpau"
+                                                             << "xv"
+                                                             << "x11");
             }
-            int voValue = m_pSettings->getOption("base.decode.Videoout").toInt();
-            if (voValue > 0) {
-                auto videoFamily = m_pSettings->option("base.decode.Videoout");
-                QString vo = videoFamily.data()->data("items").toStringList().at(voValue);
-                qDebug() << "X11: Configuring decode options for video output:" << vo;
 
-                if (vo.contains("vaapi")) {
-                    if (hwdecFamily)
-                        hwdecFamily->setData("items", QStringList() << "vaapi" << "vaapi-copy");
-                    qDebug() << "X11: Setting decode mode items for vaapi video output.";
-                } else if (vo.contains("vdpau")) {
-                    if (hwdecFamily)
-                        hwdecFamily->setData("items", QStringList() << "vdpau" << "vdpau-copy");
-                    qDebug() << "X11: Setting decode mode items for vdpau video output.";
-                } else if (vo.contains("xv") || vo.contains("x11")) {
-                    if (hwdecFamily)
-                        hwdecFamily->setData("items", QStringList() << "vdpau" << "vdpau-copy");
-                    qDebug() << "X11: Setting decode mode items for xv/x11 video output.";
-                } else {
-                    if (hwdecFamily)
-                        hwdecFamily->setData("items", QStringList() << "vaapi" << "vaapi-copy" << "vdpau" << "vdpau-copy" << "nvdec" << "nvdec-copy" << "rkmpp");
-                    qDebug() << "X11: Setting default decode mode items for other video output.";
-                }
+            int voValue = m_pSettings->getOption("base.decode.Videoout").toInt();
+
+            auto videoFamily = m_pSettings->option("base.decode.Videoout");
+            QString vo = videoFamily.data()->data("items").toStringList().at(voValue);
+            if (vo.contains("vaapi")) {
+                auto decodeFamily = m_pSettings->option("base.decode.Decodemode");
+                if (decodeFamily)
+                    decodeFamily->setData("items", QStringList() << "vaapi"
+                                                                 << "vaapi-copy");
+            } else if (vo.contains("vdpau")) {
+                auto decodeFamily = m_pSettings->option("base.decode.Decodemode");
+                if (decodeFamily)
+                    decodeFamily->setData("items", QStringList() << "vdpau"
+                                                                 << "vdpau-copy");
+            } else if (vo.contains("xv") || vo.contains("x11")) {
+                auto decodeFamily = m_pSettings->option("base.decode.Decodemode");
+                if (decodeFamily)
+                    decodeFamily->setData("items", QStringList() << "vdpau"
+                                                                 << "vdpau-copy");
             } else {
-                qDebug() << "X11: Video output value is 0, skipping decode option configuration.";
+                auto decodeFamily = m_pSettings->option("base.decode.Decodemode");
+                if (decodeFamily)
+                    decodeFamily->setData("items", QStringList() << "vaapi"
+                                                                 << "vaapi-copy"
+                                                                 << "vdpau"
+                                                                 << "vdpau-copy"
+                                                                 << "nvdec"
+                                                                 << "nvdec-copy"
+                                                                 << "rkmpp");
             }
         }
     }
