@@ -424,6 +424,7 @@ protected:
     void mouseDoubleClickEvent(QMouseEvent *pEvent) override;
     void mouseReleaseEvent(QMouseEvent *pEvent) override;
     void focusInEvent(QFocusEvent *pEvent) override;
+    void focusOutEvent(QFocusEvent *pEvent) override;
     void wheelEvent(QWheelEvent *pEvent) override;
     void keyPressEvent(QKeyEvent *pEvent) override;
     void keyReleaseEvent(QKeyEvent *pEvent) override;
@@ -599,6 +600,8 @@ private:
     bool m_bHaveFile;                                 ///导入是否包含文件（用于导入文件或文件夹）
     DSettingsDialog *m_pDSettingDilog{nullptr};
     QOpenGLWidget *m_backgroundWidget {nullptr};
+    bool m_bMaxByScreenRemoved {false};
+    QRect m_mwdRect;
 };
 };
 
