@@ -17,6 +17,7 @@
 #include <QSvgRenderer>
 
 #include <random>
+#include <libffmpegthumbnailer/videothumbnailerc.h>
 extern "C" {
 #include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
@@ -24,6 +25,8 @@ extern "C" {
 #include <libavutil/avutil.h>
 }
 
+DGUI_USE_NAMESPACE
+
 typedef int (*mvideo_avformat_open_input)(AVFormatContext **ps, const char *url, AVInputFormat *fmt, AVDictionary **options);
 typedef int (*mvideo_avformat_find_stream_info)(AVFormatContext *ic, AVDictionary **options);
 typedef int (*mvideo_av_find_best_stream)(AVFormatContext *ic, enum AVMediaType type, int wanted_stream_nb, int related_stream, AVCodec **decoder_ret, int flags);
@@ -37,6 +40,23 @@ typedef int (*mvideo_avcodec_parameters_to_context)(AVCodecContext *codec, const
 typedef int (*mvideo_avcodec_open2)(AVCodecContext *avctx, const AVCodec *codec, AVDictionary **options);
 typedef void (*mvideo_avcodec_free_context)(AVCodecContext **avctx);
 
+video_thumbnailer *m_video_thumbnailer = nullptr;
+image_data *m_image_data = nullptr;
+
+typedef video_thumbnailer *(*mvideo_thumbnailer)();
+typedef void (*mvideo_thumbnailer_destroy)(video_thumbnailer *thumbnailer);
+/* create image_data structure */
+typedef image_data *(*mvideo_thumbnailer_create_image_data)(void);
+/* destroy image_data structure */
+typedef void (*mvideo_thumbnailer_destroy_image_data)(image_data *data);
+typedef int (*mvideo_thumbnailer_generate_thumbnail_to_buffer)(video_thumbnailer *thumbnailer, const char *movie_filename, image_data *generated_image_data);
+
+mvideo_thumbnailer m_mvideo_thumbnailer = nullptr;
+mvideo_thumbnailer_destroy m_mvideo_thumbnailer_destroy = nullptr;
+mvideo_thumbnailer_create_image_data m_mvideo_thumbnailer_create_image_data = nullptr;
+mvideo_thumbnailer_destroy_image_data m_mvideo_thumbnailer_destroy_image_data = nullptr;
+mvideo_thumbnailer_generate_thumbnail_to_buffer m_mvideo_thumbnailer_generate_thumbnail_to_buffer = nullptr;
+
 
 mvideo_avformat_open_input g_mvideo_avformat_open_input = nullptr;
 mvideo_avformat_find_stream_info g_mvideo_avformat_find_stream_info = nullptr;
@@ -338,9 +358,9 @@ struct MovieInfo PlaylistModel::parseFromFile(const QFileInfo &fi, bool *ok)
         mi.strFmtName = av_ctx->iformat->long_name;
 #endif
 
-        if (videoStream->r_frame_rate.den != 0) {
+        if (videoStream->avg_frame_rate.den != 0) {
             qDebug() << "Video frame rate denominator is not zero, calculating fps.";
-            mi.fps = videoStream->r_frame_rate.num / videoStream->r_frame_rate.den;
+            mi.fps = static_cast<int>(round(static_cast<double>(videoStream->avg_frame_rate.num) / videoStream->avg_frame_rate.den));
         } else {
             qDebug() << "Video frame rate denominator is zero, setting fps to 0.";
             mi.fps = 0;
@@ -697,22 +717,22 @@ void PlaylistModel::loadPlaylist()
     qDebug() << "Exiting PlaylistModel::loadPlaylist()";
 }
 
-bool PlaylistModel::getThumanbilRunning()
+bool PlaylistModel::getThumbnailRunning()
 {
-    qDebug() << "Entering PlaylistModel::getThumanbilRunning()";
-    if (m_getThumanbil) {
-        if (m_getThumanbil->isRunning()) {
-            qDebug() << "m_getThumanbil is running";
+    qDebug() << "Entering PlaylistModel::getThumbnailRunning()";
+    if (m_getThumbnail) {
+        if (m_getThumbnail->isRunning()) {
+            qDebug() << "m_getThumbnail is running";
             return true;
         } else {
-            qDebug() << "m_getThumanbil is not running";
+            qDebug() << "m_getThumbnail is not running";
             return false;
         }
     } else {
-        qDebug() << "m_getThumanbil is null";
+        qDebug() << "m_getThumbnail is null";
         return false;
     }
-    qDebug() << "Exiting PlaylistModel::getThumanbilRunning()";
+    qDebug() << "Exiting PlaylistModel::getThumbnailRunning()";
 }
 
 MovieInfo PlaylistModel::getMovieInfo(const QUrl &url, bool *is)
@@ -1343,17 +1363,17 @@ void PlaylistModel::delayedAppendAsync(const QList<QUrl> &urls)
 
     qInfo() << "not wayland";
     if (QThread::idealThreadCount() > 1) {
-        if (!m_getThumanbil) {
-            m_getThumanbil = new GetThumanbil(this, t_urls);
-            connect(m_getThumanbil, &GetThumanbil::finished, this, &PlaylistModel::onAsyncFinished);
-            connect(m_getThumanbil, &GetThumanbil::updateItem, this, &PlaylistModel::onAsyncUpdate, Qt::BlockingQueuedConnection);
-            m_getThumanbil->start();
+        if (!m_getThumbnail) {
+            m_getThumbnail = new GetThumbnail(this, t_urls);
+            connect(m_getThumbnail, &GetThumbnail::finished, this, &PlaylistModel::onAsyncFinished);
+            connect(m_getThumbnail, &GetThumbnail::updateItem, this, &PlaylistModel::onAsyncUpdate, Qt::BlockingQueuedConnection);
+            m_getThumbnail->start();
         } else {
-            if (m_getThumanbil->isRunning()) {
+            if (m_getThumbnail->isRunning()) {
                 m_tempList.append(t_urls);
             } else {
-                m_getThumanbil->setUrls(t_urls);
-                m_getThumanbil->start();
+                m_getThumbnail->setUrls(t_urls);
+                m_getThumbnail->start();
             }
         }
         _pendingJob.clear();
@@ -1417,13 +1437,13 @@ void PlaylistModel::onAsyncFinished()
 {
     qDebug() << "Entering PlaylistModel::onAsyncFinished()";
     //qInfo() << fil.size();
-    m_getThumanbil->clearItem();
+    m_getThumbnail->clearItem();
     //handleAsyncAppendResults(fil);
     if (!m_tempList.isEmpty()) {
         qDebug() << "m_tempList is not empty, set urls and start";
-        m_getThumanbil->setUrls(m_tempList);
+        m_getThumbnail->setUrls(m_tempList);
         m_tempList.clear();
-        m_getThumanbil->start();
+        m_getThumbnail->start();
     }
     qDebug() << "Exiting PlaylistModel::onAsyncFinished()";
 }
@@ -1765,13 +1785,13 @@ PlaylistModel::~PlaylistModel()
         qDebug() << "Preserving playlist on exit";
     }
 #endif
-    if (m_getThumanbil) {
-        if (m_getThumanbil->isRunning()) {
+    if (m_getThumbnail) {
+        if (m_getThumbnail->isRunning()) {
             qDebug() << "Stopping running thumbnail generation thread";
-            m_getThumanbil->stop();
+            m_getThumbnail->stop();
         }
-        m_getThumanbil->deleteLater();
-        m_getThumanbil = nullptr;
+        m_getThumbnail->deleteLater();
+        m_getThumbnail = nullptr;
         qDebug() << "Thumbnail generator scheduled for deletion";
     }
     if (m_video_thumbnailer != nullptr) {
@@ -1941,8 +1961,8 @@ MovieInfo MovieInfo::parseFromFile(const QFileInfo &fi, bool *ok)
 #ifdef _MOVIE_USE_
     mi.strFmtName = av_ctx->iformat->long_name;
 #endif
-    if (av_stream->r_frame_rate.den != 0) {
-        mi.fps = av_stream->r_frame_rate.num / av_stream->r_frame_rate.den;
+    if (av_stream->avg_frame_rate.den != 0) {
+        mi.fps = static_cast<int>(round(static_cast<double>(av_stream->avg_frame_rate.num) / av_stream->avg_frame_rate.den));
     } else {
         mi.fps = 0;
     }
