@@ -8,32 +8,18 @@
 #include <QtWidgets>
 //#include <QtConcurrent>
 #include <DGuiApplicationHelper>
-#include <DGuiApplicationHelper>
-#include <libffmpegthumbnailer/videothumbnailerc.h>
 
 #include "utils.h"
 #include <QNetworkReply>
 #include <QMutex>
 
-#include <libffmpegthumbnailer/videothumbnailerc.h>
-
 #define THUMBNAIL_SIZE 500
 #define SEEK_TIME "00:00:01"
 
-DGUI_USE_NAMESPACE
-
-typedef video_thumbnailer *(*mvideo_thumbnailer)();
-typedef void (*mvideo_thumbnailer_destroy)(video_thumbnailer *thumbnailer);
-/* create image_data structure */
-typedef image_data *(*mvideo_thumbnailer_create_image_data)(void);
-/* destroy image_data structure */
-typedef void (*mvideo_thumbnailer_destroy_image_data)(image_data *data);
-typedef int (*mvideo_thumbnailer_generate_thumbnail_to_buffer)(video_thumbnailer *thumbnailer, const char *movie_filename, image_data *generated_image_data);
-
 namespace dmr {
 class PlayerEngine;
 class LoadThread;
-class GetThumanbil;
+class GetThumbnail;
 
 struct MovieInfo {
     bool valid;
@@ -225,10 +211,10 @@ public:
     };
     void loadPlaylist();
     /**
-     * @brief getThumanbilRunning 获取加载线程是否运行
+     * @brief getThumbnailRunning 获取加载线程是否运行
      * @return 返回是否正在运行
      */
-    bool getThumanbilRunning();
+    bool getThumbnailRunning();
 
     //获取视频信息
     MovieInfo getMovieInfo(const QUrl &url, bool *is);
@@ -287,21 +273,12 @@ private:
 
     bool _userRequestingItem {false};
 
-    video_thumbnailer *m_video_thumbnailer = nullptr;
-    image_data *m_image_data = nullptr;
-
-    mvideo_thumbnailer m_mvideo_thumbnailer = nullptr;
-    mvideo_thumbnailer_destroy m_mvideo_thumbnailer_destroy = nullptr;
-    mvideo_thumbnailer_create_image_data m_mvideo_thumbnailer_create_image_data = nullptr;
-    mvideo_thumbnailer_destroy_image_data m_mvideo_thumbnailer_destroy_image_data = nullptr;
-    mvideo_thumbnailer_generate_thumbnail_to_buffer m_mvideo_thumbnailer_generate_thumbnail_to_buffer = nullptr;
-
     PlayerEngine *_engine {nullptr};
 
     QString _playlistFile;
 
     LoadThread *m_ploadThread;
-    GetThumanbil *m_getThumanbil {nullptr};
+    GetThumbnail *m_getThumbnail {nullptr};
     QMutex *m_pdataMutex;
     bool m_brunning;
     QList<QUrl> m_tempList;
@@ -334,17 +311,17 @@ private:
     QSet<QString> _urlsInJob;  // url list
 };
 
-class GetThumanbil : public QThread
+class GetThumbnail : public QThread
 {
     Q_OBJECT
 public:
-    GetThumanbil(PlaylistModel *model, const QList<QUrl> &urls): m_model(model), m_urls(urls)
+    GetThumbnail(PlaylistModel *model, const QList<QUrl> &urls): m_model(model), m_urls(urls)
     {
 //        m_model = model;
 //        m_urls = urls;
         m_mutex = new QMutex;
     };
-    ~GetThumanbil()
+    ~GetThumbnail()
     {
         m_stop = true;
         delete m_mutex;
