@@ -24,6 +24,29 @@ using namespace std;
 
 static bool isWayland = false;
 
+QStringList runPipeProcess(const QString &command, const QString &filter)
+{
+    QProcess process;
+    process.start(command);
+    process.waitForFinished();
+
+    QString comStr = process.readAllStandardOutput();
+    QStringList lines = comStr.split('\n');
+    QStringList filteredLines;
+    if(filter.isEmpty()) {
+        return lines; //返回所有
+    }
+    // 过滤包含指定关键字的行
+    for (const QString &line : lines) {
+        if (line.contains(filter, Qt::CaseInsensitive)) {
+            filteredLines.append(line);
+        }
+    }
+
+    // 合并过滤后的行并返回
+    return filteredLines;   // 返回以换行符分隔的字符串
+}
+
 void ShowInFileManager(const QString &path)
 {
     qDebug() << "Entering ShowInFileManager() with path:" << path;
@@ -709,7 +732,7 @@ void getPlayProperty(const char *path, QMap<QString, QString> *&proMap)
     QFileInfo fi(path);
     if ((fi.exists() && fi.isFile()) && fi.isReadable()) {
         QFile file(path);
-        if (file.open(QIODevice::ReadOnly) | QIODevice::Text) {
+        if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             QByteArray t;
             int index = 0;
             while (!file.atEnd()) {
@@ -720,18 +743,100 @@ void getPlayProperty(const char *path, QMap<QString, QString> *&proMap)
                     QString temp = list.back();
                     temp = temp.mid(0, temp.length() - 1);//去除/n
                     proMap->insert(list.first(), temp);
-                    qDebug() << "Added property:" << list.first() << "=" << temp;
+                    qInfo() << "Read config line: key:" << list.first() << "value:" << temp;
                 } else {
-                    qWarning() << "Invalid config line:" << index << t;
+                    qWarning() << __func__ << QString("ERROR! config line: %1 (line No: %2)").arg(QString(t)).arg(index);
                     continue;
                 }
             }
+            file.close();
+        } else {
+            qWarning() << __func__ << "File open ERROR, file path:" << path;
         }
-        file.close();
     } else {
-        qWarning() << "Invalid file path or permissions:" << path;
+        qWarning() << __func__ << "File not exist, file path:" << path;
     }
 #endif
 }
+
+QVariant readDBusProperty(const QString &sService, const QString &sPath, const QString &sInterface, const char *pPropert)
+{
+    // 创建QDBusInterface接口
+    QDBusInterface ainterface(sService, sPath,
+                              sInterface,
+                              QDBusConnection::sessionBus());
+    if (!ainterface.isValid()) {
+        QVariant v(0) ;
+        return  v;
+    }
+    //调用远程的value方法
+    QVariant v = ainterface.property(pPropert);
+    return  v;
+}
+
+void switchToDefaultSink()
+{
+
+    QVariant v = readDBusProperty("com.deepin.daemon.Audio", "/com/deepin/daemon/Audio",
+                                             "com.deepin.daemon.Audio", "SinkInputs");
+
+    if (!v.isValid())
+        return;
+
+    QList<QDBusObjectPath> allSinkInputsList = v.value<QList<QDBusObjectPath>>();
+
+    int inputIndex = -1; //当前音乐的索引值
+    int curSinkIndex = -1;
+    for (auto curPath : allSinkInputsList) {
+        QVariant nameV = readDBusProperty("com.deepin.daemon.Audio", curPath.path(),
+                                                     "com.deepin.daemon.Audio.SinkInput", "Name");
+
+        if (!nameV.isValid() || nameV.toString() != QObject::tr("Movie"))
+            continue;
+        QString path =  curPath.path();
+        int indx = path.lastIndexOf("/");
+        path = path.mid(indx + 1, path.size() - indx); //最后一个'/'，然后移出Sink关键字
+        if (path.size() > 9) {
+            inputIndex = path.remove(0, 9).toInt();
+            //break;
+        } else
+            return;
+
+        QVariant sinkV = readDBusProperty("com.deepin.daemon.Audio", curPath.path(),
+                                                     "com.deepin.daemon.Audio.SinkInput", "SinkIndex");
+        if (!sinkV.isValid())
+            continue;
+        curSinkIndex = sinkV.toInt();
+    }
+
+    if (inputIndex == -1)
+        return;
+
+    //获取默认输出设备
+    QVariant varsink = readDBusProperty("com.deepin.daemon.Audio", "/com/deepin/daemon/Audio",
+                                                   "com.deepin.daemon.Audio", "DefaultSink");
+    if (!varsink.isValid())
+        return;
+    QString sinkpath = varsink.value<QDBusObjectPath >().path();
+    int sinkindex = sinkpath.lastIndexOf("/");
+    sinkpath = sinkpath.mid(sinkindex + 1, sinkpath.size() - sinkindex);//最后一个'/'
+    if (sinkpath.size() > 4) {
+        sinkindex = sinkpath.remove(0, 4).toInt();
+    } else
+        return;
+
+    qInfo() <<"default sink: " << sinkindex << "\tcurrent sink: " << curSinkIndex << "\tsink input index: " << inputIndex;
+
+    if (curSinkIndex == sinkindex) {
+        return;
+    }
+    QProcess proc;
+    QStringList sList;
+    sList.append("move-sink-input");
+    sList.append(QString::number(inputIndex));
+    sList.append(QString::number(sinkindex));
+    proc.start("pacmd", sList);
+    proc.waitForFinished();
+}
 }
 }
