@@ -174,12 +174,8 @@ void killOldMovie()
     qInfo() << "kill old movie process";
     QString processName = "deepin-movie";
 
-    QProcess psProcess;
-    psProcess.start("bash", QStringList() << "-c" << "ps -eo pid,lstart,cmd | grep deepin-movie");
-    psProcess.waitForFinished();
-    QString output = psProcess.readAllStandardOutput();
+    QStringList lines = dmr::utils::runPipeProcess("ps -eo pid,lstart,cmd", "deepin-movie");
 
-    QStringList lines = output.split("\n");
     QStringList earlierProcessPids;
     QDateTime earliestStartTime;
 
@@ -219,6 +215,46 @@ void killOldMovie()
     qInfo() << "Kill old movie process end";
 }
 
+void getDecodeConfigInfo() {
+    auto settings = Settings::get().settings();
+    int selectIndex = settings->getOption(QString("base.decode.select")).toInt();
+    auto selectConfig = settings->option("base.decode.select")->data("items").toStringList();
+    if (selectIndex >= 0 && selectIndex < selectConfig.size()) {
+        QString selectModeOpt = selectConfig.at(selectIndex);
+        // 专业模式
+        if (selectIndex == 3) {
+            int effectIdx = settings->getOption(QString("base.decode.Effect")).toInt();
+            QStringList effectList = settings->option("base.decode.Effect")->data("items").toStringList();
+            QString effectOpt;
+            if (effectIdx >= 0 && effectIdx < effectList.size()) {
+                effectOpt = effectList.at(effectIdx);
+            }
+
+            int decodeIdx = settings->getOption(QString("base.decode.Decodemode")).toInt();
+            QStringList decodeList = settings->option("base.decode.Decodemode")->data("items").toStringList();
+            QString decodeMode;
+            if (decodeIdx >= 0 && decodeIdx < decodeList.size()) {
+                decodeMode = decodeList.at(decodeIdx);
+            }
+
+            int voIdx = settings->getOption(QString("base.decode.Videoout")).toInt();
+            QStringList voList = settings->option("base.decode.Videoout")->data("items").toStringList();
+            QString voMode;
+            if (voIdx >= 0 && voIdx < voList.size()) {
+                voMode = voList.at(voIdx);
+            }
+
+            if (utils::check_wayland_env()) {
+                qDebug() << "Select-Mode:" << selectModeOpt << "Hardware-Decode:" << decodeMode;
+            } else {
+                qDebug() << "Select-Mode:" << selectModeOpt << "Effect:" << effectOpt << "Hardware-Decode:" << decodeMode << "Render:" << voMode;
+            }
+        } else {
+            qDebug() << "Select-Mode:" << selectModeOpt;
+        }
+    }
+}
+
 int main(int argc, char *argv[])
 {
     qInfo() << "Starting deepin-movie application";
@@ -391,6 +427,14 @@ int main(int argc, char *argv[])
     Dtk::Core::DLogManager::registerFileAppender();
     qInfo() << "File logging initialized at:" << Dtk::Core::DLogManager::getlogFilePath();
 
+    if (dmr::Settings::get().settings()->getOption("set.start.crash").toInt() == 1) {
+        dmr::Settings::get().settings()->setOption("base.decode.select", 0);
+        dmr::Settings::get().settings()->setOption("base.decode.Decodemode", 0);
+        dmr::Settings::get().settings()->setOption("base.decode.Videoout", 0);
+    }
+
+    dmr::Settings::get().crashCheck();
+
     bool singleton = !dmr::Settings::get().isSet(dmr::Settings::MultipleInstance);
     qDebug() << "Singleton mode:" << (singleton ? "enabled" : "disabled");
     QString movieName = "";
@@ -398,7 +442,6 @@ int main(int argc, char *argv[])
         qDebug() << "Function call option is set.";
         movieName = getFunctionMovieName();
     }
-
     if (singleton && !runSingleInstance()) {
         qDebug() << "Singleton mode enabled and another instance running.";
         if (clm.isSet("restart")) {
@@ -406,6 +449,7 @@ int main(int argc, char *argv[])
             qDebug() << "Restart option is set.";
             sleep(2);
             qDebug() << "Waited for 2 seconds.";
+            qWarning() << "killOldMovie";
             if (!runSingleInstance()) {
                 qWarning() << "Failed to acquire single instance lock - killing old instance";
                 qDebug() << "Failed to acquire single instance lock during restart, killing old movie.";
@@ -524,6 +568,7 @@ int main(int argc, char *argv[])
         ApplicationAdaptor adaptor(&mw);
         QDBusConnection::sessionBus().registerService("com.deepin.movie");
         QDBusConnection::sessionBus().registerObject("/", &mw);
+        getDecodeConfigInfo();
 
         int ret = app->exec();
         if (ret == 2)
@@ -558,6 +603,7 @@ int main(int argc, char *argv[])
         Platform_ApplicationAdaptor adaptor(&platform_mw);
         QDBusConnection::sessionBus().registerService("com.deepin.movie");
         QDBusConnection::sessionBus().registerObject("/", &platform_mw);
+        getDecodeConfigInfo();
         int ret = app->exec();
         if (ret == 2)
             execv( app->applicationFilePath().toUtf8().data(), nullptr);
