@@ -50,6 +50,7 @@ Platform_VolumeSlider::Platform_VolumeSlider(Platform_MainWindow *mw, QWidget *p
     m_slider = new DSlider(Qt::Vertical, this);
     m_slider->setFixedWidth(24);
     m_slider->setIconSize(QSize(15, 15));
+    m_slider->setMouseWheelEnabled(true);
     m_slider->installEventFilter(this);
     m_slider->show();
     m_slider->slider()->setRange(0, 100);
@@ -87,7 +88,7 @@ Platform_VolumeSlider::Platform_VolumeSlider(Platform_MainWindow *mw, QWidget *p
 void Platform_VolumeSlider::initVolume()
 {
     qDebug() << "Entering initVolume function";
-    QTimer::singleShot(500, this, [ = ] { //延迟加载等待信号槽连接
+    QTimer::singleShot(50, this, [ = ] { //延迟加载等待信号槽连接
         int nVolume = Settings::get().internalOption("global_volume").toInt();
         bool bMute = Settings::get().internalOption("mute").toBool();
 
@@ -111,7 +112,7 @@ QString Platform_VolumeSlider::readSinkInputPath()
     qDebug() << "Entering readSinkInputPath function";
     QString strPath = "";
 
-    QVariant v = ApplicationAdaptor::redDBusProperty("org.deepin.dde.Audio1", "/org/deepin/dde/Audio1",
+    QVariant v = ApplicationAdaptor::readDBusProperty("org.deepin.dde.Audio1", "/org/deepin/dde/Audio1",
                                                      "org.deepin.dde.Audio1", "SinkInputs");
 
     if (!v.isValid())
@@ -123,7 +124,7 @@ QString Platform_VolumeSlider::readSinkInputPath()
     QList<QDBusObjectPath> allSinkInputsList = v.value<QList<QDBusObjectPath> >();
 
     for (auto curPath : allSinkInputsList) {
-        QVariant nameV = ApplicationAdaptor::redDBusProperty("org.deepin.dde.Audio1", curPath.path(),
+        QVariant nameV = ApplicationAdaptor::readDBusProperty("org.deepin.dde.Audio1", curPath.path(),
                                                              "org.deepin.dde.Audio1.SinkInput", "Name");
         QString strMovie = QObject::tr("Movie");
         if (!nameV.isValid() || (!nameV.toString().contains(strMovie, Qt::CaseInsensitive) && !nameV.toString().contains("deepin movie", Qt::CaseInsensitive))) {
@@ -141,6 +142,10 @@ QString Platform_VolumeSlider::readSinkInputPath()
 void Platform_VolumeSlider::setMute(bool muted)
 {
     qDebug() << "Setting mute state to:" << muted;
+    if (m_bIsMute != muted || m_nVolume == 0) {
+        return;
+    }
+
     QString sinkInputPath = readSinkInputPath();
 
     if (!sinkInputPath.isEmpty()) {
@@ -168,6 +173,8 @@ void Platform_VolumeSlider::updatePoint(QPoint point)
     QRect view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
     m_point = point + QPoint(view_rect.width() - (TOOLBOX_BUTTON_WIDTH * 3 + 40 + (VOLSLIDER_WIDTH - TOOLBOX_BUTTON_WIDTH) / 2),
                              view_rect.height() - TOOLBOX_HEIGHT - VOLSLIDER_HEIGHT);
+    // 控件顶点更新后，同步移动控件到正确位置
+    move(m_point);
 }
 void Platform_VolumeSlider::popup()
 {
