@@ -45,6 +45,7 @@ VolumeSlider::VolumeSlider(MainWindow *mw, QWidget *parent)
     m_slider = new DSlider(Qt::Vertical, this);
     m_slider->setFixedWidth(24);
     m_slider->setIconSize(QSize(15, 15));
+    m_slider->setMouseWheelEnabled(true);
     m_slider->installEventFilter(this);
     m_slider->show();
     m_slider->slider()->setRange(0, 100);
@@ -82,7 +83,7 @@ VolumeSlider::VolumeSlider(MainWindow *mw, QWidget *parent)
 void VolumeSlider::initVolume()
 {
     qDebug() << "Initializing volume slider";
-    QTimer::singleShot(1500, this, [ = ] { //延迟加载等待信号槽连接
+    QTimer::singleShot(50, this, [ = ] { //延迟加载等待信号槽连接
         int nVolume = Settings::get().internalOption("global_volume").toInt();
         bool bMute = Settings::get().internalOption("mute").toBool();
 
@@ -105,8 +106,8 @@ QString VolumeSlider::readSinkInputPath()
     qDebug() << "Reading sink input path";
     QString strPath = "";
 
-    QVariant v = ApplicationAdaptor::redDBusProperty("org.deepin.dde.Audio1", "/org/deepin/dde/Audio1",
-                                                     "org.deepin.dde.Audio1", "SinkInputs");
+    QVariant v = ApplicationAdaptor::readDBusProperty("org.deepin.dde.Audio1", "/org/deepin/dde/Audio1",
+                                                      "org.deepin.dde.Audio1", "SinkInputs");
 
     if (!v.isValid()) {
         qWarning() << "Sink inputs property is not valid";
@@ -116,8 +117,8 @@ QString VolumeSlider::readSinkInputPath()
     QList<QDBusObjectPath> allSinkInputsList = v.value<QList<QDBusObjectPath> >();
 
     for (auto curPath : allSinkInputsList) {
-        QVariant nameV = ApplicationAdaptor::redDBusProperty("org.deepin.dde.Audio1", curPath.path(),
-                                                             "org.deepin.dde.Audio1.SinkInput", "Name");
+        QVariant nameV = ApplicationAdaptor::readDBusProperty("org.deepin.dde.Audio1", curPath.path(),
+                                                              "org.deepin.dde.Audio1.SinkInput", "Name");
         QString strMovie = QObject::tr("Movie");
         if (!nameV.isValid() || (!nameV.toString().contains(strMovie, Qt::CaseInsensitive) && !nameV.toString().contains("deepin movie", Qt::CaseInsensitive)))
             continue;
